@@ -1,12 +1,11 @@
 package HPC::Runner::Command::Utils::ManyConfigs;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use 5.010;
 use utf8;
 
 use namespace::autoclean;
-
 use MooseX::App::Role;
 
 use Config::Any;
@@ -64,7 +63,8 @@ option 'search_path' => (
         map_search_path     => 'map',
         has_search_path     => 'count',
     },
-    documentation => 'Enable a search path for configs. Default is the home dir and your cwd.'
+    documentation =>
+      'Enable a search path for configs. Default is the home dir and your cwd.'
 );
 
 has 'filter_keys' => (
@@ -107,7 +107,7 @@ has '_config_data' => (
 
 sub BUILD { }
 
-after 'BUILD' => sub {
+before 'BUILD' => sub {
     my $self = shift;
 
     return if $self->no_configs;
@@ -199,6 +199,7 @@ sub apply_attributes {
             }
             catch {
                 warn 'You tried to assign ' . $key . ' to ' . $value . "\n";
+
                 #TODO Add logging
             };
         }
